Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/moses-smt/mosesdecoder.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/moses/FF
diff options
context:
space:
mode:
authorHieu Hoang <hieuhoang@gmail.com>2015-11-04 18:10:45 +0300
committerHieu Hoang <hieuhoang@gmail.com>2015-11-04 18:10:45 +0300
commit4078c30a42690a87b6db0fc04e655f9bcfa8671e (patch)
tree3034f9cfa58ad5fe84e37225471692410c264fbd /moses/FF
parente87dd15f4a320febefd8c41d19e3ed0b939f5d47 (diff)
estimatedScore -> estimatedScores
Diffstat (limited to 'moses/FF')
-rw-r--r--moses/FF/BleuScoreFeature.h4
-rw-r--r--moses/FF/ConstrainedDecoding.h4
-rw-r--r--moses/FF/ControlRecombination.h4
-rw-r--r--moses/FF/CountNonTerms.cpp2
-rw-r--r--moses/FF/CountNonTerms.h4
-rw-r--r--moses/FF/CoveredReferenceFeature.cpp6
-rw-r--r--moses/FF/CoveredReferenceFeature.h4
-rw-r--r--moses/FF/DecodeFeature.h4
-rw-r--r--moses/FF/DeleteRules.cpp4
-rw-r--r--moses/FF/DeleteRules.h4
-rw-r--r--moses/FF/DistortionScoreProducer.h4
-rw-r--r--moses/FF/DynamicCacheBasedLanguageModel.cpp2
-rw-r--r--moses/FF/DynamicCacheBasedLanguageModel.h4
-rw-r--r--moses/FF/FeatureFunction.h8
-rw-r--r--moses/FF/GlobalLexicalModel.cpp2
-rw-r--r--moses/FF/GlobalLexicalModel.h4
-rw-r--r--moses/FF/GlobalLexicalModelUnlimited.h4
-rw-r--r--moses/FF/HyperParameterAsWeight.h4
-rw-r--r--moses/FF/InputFeature.cpp2
-rw-r--r--moses/FF/InputFeature.h4
-rw-r--r--moses/FF/LexicalReordering/LexicalReordering.h4
-rw-r--r--moses/FF/MaxSpanFreeNonTermSource.cpp4
-rw-r--r--moses/FF/MaxSpanFreeNonTermSource.h4
-rw-r--r--moses/FF/Model1Feature.cpp2
-rw-r--r--moses/FF/Model1Feature.h4
-rw-r--r--moses/FF/NieceTerminal.cpp4
-rw-r--r--moses/FF/NieceTerminal.h4
-rw-r--r--moses/FF/OSM-Feature/OpSequenceModel.cpp4
-rw-r--r--moses/FF/OSM-Feature/OpSequenceModel.h4
-rw-r--r--moses/FF/PhraseBoundaryFeature.h4
-rw-r--r--moses/FF/PhraseLengthFeature.cpp2
-rw-r--r--moses/FF/PhraseLengthFeature.h4
-rw-r--r--moses/FF/PhraseOrientationFeature.cpp2
-rw-r--r--moses/FF/PhraseOrientationFeature.h4
-rw-r--r--moses/FF/PhrasePairFeature.cpp4
-rw-r--r--moses/FF/PhrasePairFeature.h4
-rw-r--r--moses/FF/PhrasePenalty.cpp2
-rw-r--r--moses/FF/PhrasePenalty.h4
-rw-r--r--moses/FF/ReferenceComparison.h4
-rw-r--r--moses/FF/RulePairUnlexicalizedSource.cpp2
-rw-r--r--moses/FF/RulePairUnlexicalizedSource.h4
-rw-r--r--moses/FF/RuleScope.cpp6
-rw-r--r--moses/FF/RuleScope.h4
-rw-r--r--moses/FF/SetSourcePhrase.cpp2
-rw-r--r--moses/FF/SetSourcePhrase.h4
-rw-r--r--moses/FF/SkeletonStatefulFF.cpp4
-rw-r--r--moses/FF/SkeletonStatefulFF.h4
-rw-r--r--moses/FF/SkeletonStatelessFF.cpp4
-rw-r--r--moses/FF/SkeletonStatelessFF.h4
-rw-r--r--moses/FF/SoftMatchingFeature.h4
-rw-r--r--moses/FF/SoftSourceSyntacticConstraintsFeature.cpp2
-rw-r--r--moses/FF/SoftSourceSyntacticConstraintsFeature.h4
-rw-r--r--moses/FF/SourceGHKMTreeInputMatchFeature.cpp2
-rw-r--r--moses/FF/SourceGHKMTreeInputMatchFeature.h4
-rw-r--r--moses/FF/SourceWordDeletionFeature.cpp2
-rw-r--r--moses/FF/SourceWordDeletionFeature.h4
-rw-r--r--moses/FF/SpanLength.cpp4
-rw-r--r--moses/FF/SpanLength.h4
-rw-r--r--moses/FF/SparseHieroReorderingFeature.h4
-rw-r--r--moses/FF/SyntaxRHS.cpp4
-rw-r--r--moses/FF/SyntaxRHS.h4
-rw-r--r--moses/FF/TargetBigramFeature.h4
-rw-r--r--moses/FF/TargetNgramFeature.h4
-rw-r--r--moses/FF/TargetWordInsertionFeature.cpp2
-rw-r--r--moses/FF/TargetWordInsertionFeature.h4
-rw-r--r--moses/FF/TreeStructureFeature.h4
-rw-r--r--moses/FF/UnalignedWordCountFeature.cpp2
-rw-r--r--moses/FF/UnalignedWordCountFeature.h4
-rw-r--r--moses/FF/UnknownWordPenaltyProducer.h4
-rw-r--r--moses/FF/WordPenaltyProducer.cpp2
-rw-r--r--moses/FF/WordPenaltyProducer.h4
-rw-r--r--moses/FF/WordTranslationFeature.cpp2
-rw-r--r--moses/FF/WordTranslationFeature.h4
73 files changed, 133 insertions, 133 deletions
diff --git a/moses/FF/BleuScoreFeature.h b/moses/FF/BleuScoreFeature.h
index c827c5c65..266d06b68 100644
--- a/moses/FF/BleuScoreFeature.h
+++ b/moses/FF/BleuScoreFeature.h
@@ -128,7 +128,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -137,7 +137,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
bool Enabled() const {
diff --git a/moses/FF/ConstrainedDecoding.h b/moses/FF/ConstrainedDecoding.h
index e0d4cdff3..3f28c43e1 100644
--- a/moses/FF/ConstrainedDecoding.h
+++ b/moses/FF/ConstrainedDecoding.h
@@ -45,7 +45,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
void EvaluateWithSourceContext(const InputType &input
@@ -53,7 +53,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/ControlRecombination.h b/moses/FF/ControlRecombination.h
index a75fabb5d..04f7d441b 100644
--- a/moses/FF/ControlRecombination.h
+++ b/moses/FF/ControlRecombination.h
@@ -61,14 +61,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/CountNonTerms.cpp b/moses/FF/CountNonTerms.cpp
index 4e020153e..f49aecfc8 100644
--- a/moses/FF/CountNonTerms.cpp
+++ b/moses/FF/CountNonTerms.cpp
@@ -19,7 +19,7 @@ CountNonTerms::CountNonTerms(const std::string &line)
void CountNonTerms::EvaluateInIsolation(const Phrase &sourcePhrase
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
const StaticData &staticData = StaticData::Instance();
diff --git a/moses/FF/CountNonTerms.h b/moses/FF/CountNonTerms.h
index a8b836748..a9f6e884b 100644
--- a/moses/FF/CountNonTerms.h
+++ b/moses/FF/CountNonTerms.h
@@ -16,14 +16,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/CoveredReferenceFeature.cpp b/moses/FF/CoveredReferenceFeature.cpp
index 48faded35..d4606a8ec 100644
--- a/moses/FF/CoveredReferenceFeature.cpp
+++ b/moses/FF/CoveredReferenceFeature.cpp
@@ -33,7 +33,7 @@ bool CoveredReferenceState::operator==(const FFState& other) const
void CoveredReferenceFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{}
void CoveredReferenceFeature::EvaluateWithSourceContext(const InputType &input
@@ -41,7 +41,7 @@ void CoveredReferenceFeature::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
long id = input.GetTranslationId();
boost::unordered_map<long, std::multiset<string> >::const_iterator refIt = m_refs.find(id);
@@ -54,7 +54,7 @@ void CoveredReferenceFeature::EvaluateWithSourceContext(const InputType &input
scores.push_back(covered.size());
scoreBreakdown.Assign(this, scores);
- estimatedScore->Assign(this, scores);
+ estimatedScores->Assign(this, scores);
}
void CoveredReferenceFeature::Load()
diff --git a/moses/FF/CoveredReferenceFeature.h b/moses/FF/CoveredReferenceFeature.h
index fb5ab7e15..e6fc79ff7 100644
--- a/moses/FF/CoveredReferenceFeature.h
+++ b/moses/FF/CoveredReferenceFeature.h
@@ -56,13 +56,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/DecodeFeature.h b/moses/FF/DecodeFeature.h
index a1a38de36..8d8fe22b8 100644
--- a/moses/FF/DecodeFeature.h
+++ b/moses/FF/DecodeFeature.h
@@ -76,7 +76,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
@@ -85,7 +85,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
void SetContainer(const DecodeStep *container) {
diff --git a/moses/FF/DeleteRules.cpp b/moses/FF/DeleteRules.cpp
index b72f695f7..714e0e8a8 100644
--- a/moses/FF/DeleteRules.cpp
+++ b/moses/FF/DeleteRules.cpp
@@ -41,7 +41,7 @@ void DeleteRules::Load()
void DeleteRules::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &target
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
// dense scores
size_t hash = 0;
@@ -61,7 +61,7 @@ void DeleteRules::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{}
void DeleteRules::EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/DeleteRules.h b/moses/FF/DeleteRules.h
index 754b9a241..1070aaa51 100644
--- a/moses/FF/DeleteRules.h
+++ b/moses/FF/DeleteRules.h
@@ -24,13 +24,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const;
diff --git a/moses/FF/DistortionScoreProducer.h b/moses/FF/DistortionScoreProducer.h
index ed8a2e6ce..6e6bfbaeb 100644
--- a/moses/FF/DistortionScoreProducer.h
+++ b/moses/FF/DistortionScoreProducer.h
@@ -52,7 +52,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -62,7 +62,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
};
}
diff --git a/moses/FF/DynamicCacheBasedLanguageModel.cpp b/moses/FF/DynamicCacheBasedLanguageModel.cpp
index 8ba4798fd..6f183eeec 100644
--- a/moses/FF/DynamicCacheBasedLanguageModel.cpp
+++ b/moses/FF/DynamicCacheBasedLanguageModel.cpp
@@ -88,7 +88,7 @@ void DynamicCacheBasedLanguageModel::SetParameter(const std::string& key, const
void DynamicCacheBasedLanguageModel::EvaluateInIsolation(const Phrase &sp
, const TargetPhrase &tp
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
float score = m_lower_score;
switch(m_query_type) {
diff --git a/moses/FF/DynamicCacheBasedLanguageModel.h b/moses/FF/DynamicCacheBasedLanguageModel.h
index 3f53a7d76..497283b44 100644
--- a/moses/FF/DynamicCacheBasedLanguageModel.h
+++ b/moses/FF/DynamicCacheBasedLanguageModel.h
@@ -132,14 +132,14 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/GlobalLexicalModel.cpp b/moses/FF/GlobalLexicalModel.cpp
index 7da3679b7..06e26b417 100644
--- a/moses/FF/GlobalLexicalModel.cpp
+++ b/moses/FF/GlobalLexicalModel.cpp
@@ -171,7 +171,7 @@ float GlobalLexicalModel::GetFromCacheOrScorePhrase( const TargetPhrase& targetP
void GlobalLexicalModel::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
scoreBreakdown.PlusEquals( this, GetFromCacheOrScorePhrase(targetPhrase) );
}
diff --git a/moses/FF/GlobalLexicalModel.h b/moses/FF/GlobalLexicalModel.h
index 7038fb451..d126f21f2 100644
--- a/moses/FF/GlobalLexicalModel.h
+++ b/moses/FF/GlobalLexicalModel.h
@@ -75,7 +75,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWhenApplied(const Hypothesis& hypo,
ScoreComponentCollection* accumulator) const {
@@ -89,7 +89,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/GlobalLexicalModelUnlimited.h b/moses/FF/GlobalLexicalModelUnlimited.h
index 647b81dfe..d3016568a 100644
--- a/moses/FF/GlobalLexicalModelUnlimited.h
+++ b/moses/FF/GlobalLexicalModelUnlimited.h
@@ -90,7 +90,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -100,7 +100,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
void AddFeature(ScoreComponentCollection* accumulator,
diff --git a/moses/FF/HyperParameterAsWeight.h b/moses/FF/HyperParameterAsWeight.h
index 6815b5a64..2ba653d34 100644
--- a/moses/FF/HyperParameterAsWeight.h
+++ b/moses/FF/HyperParameterAsWeight.h
@@ -21,7 +21,7 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
virtual void EvaluateWithSourceContext(const InputType &input
@@ -29,7 +29,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
virtual void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/InputFeature.cpp b/moses/FF/InputFeature.cpp
index 902ba64fc..21bae61e1 100644
--- a/moses/FF/InputFeature.cpp
+++ b/moses/FF/InputFeature.cpp
@@ -49,7 +49,7 @@ void InputFeature::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
if (m_legacy) {
//binary phrase-table does input feature itself
diff --git a/moses/FF/InputFeature.h b/moses/FF/InputFeature.h
index f03af98e8..e26eb1317 100644
--- a/moses/FF/InputFeature.h
+++ b/moses/FF/InputFeature.h
@@ -41,7 +41,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
void EvaluateWithSourceContext(const InputType &input
@@ -49,7 +49,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/LexicalReordering/LexicalReordering.h b/moses/FF/LexicalReordering/LexicalReordering.h
index e7b90afda..c47e7f037 100644
--- a/moses/FF/LexicalReordering/LexicalReordering.h
+++ b/moses/FF/LexicalReordering/LexicalReordering.h
@@ -71,7 +71,7 @@ public:
const TargetPhrase &targetPhrase,
const StackVec *stackVec,
ScoreComponentCollection& scoreBreakdown,
- ScoreComponentCollection* estimatedScore = NULL) const
+ ScoreComponentCollection* estimatedScores = NULL) const
{ }
void
@@ -83,7 +83,7 @@ public:
EvaluateInIsolation(const Phrase &source,
const TargetPhrase &targetPhrase,
ScoreComponentCollection &scoreBreakdown,
- ScoreComponentCollection &estimatedScore) const
+ ScoreComponentCollection &estimatedScores) const
{ }
bool
diff --git a/moses/FF/MaxSpanFreeNonTermSource.cpp b/moses/FF/MaxSpanFreeNonTermSource.cpp
index f1ac39633..7c75c7fd6 100644
--- a/moses/FF/MaxSpanFreeNonTermSource.cpp
+++ b/moses/FF/MaxSpanFreeNonTermSource.cpp
@@ -30,7 +30,7 @@ MaxSpanFreeNonTermSource::MaxSpanFreeNonTermSource(const std::string &line)
void MaxSpanFreeNonTermSource::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
targetPhrase.SetRuleSource(source);
}
@@ -40,7 +40,7 @@ void MaxSpanFreeNonTermSource::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
const Word &targetLHS = targetPhrase.GetTargetLHS();
diff --git a/moses/FF/MaxSpanFreeNonTermSource.h b/moses/FF/MaxSpanFreeNonTermSource.h
index 96f6682d8..700765618 100644
--- a/moses/FF/MaxSpanFreeNonTermSource.h
+++ b/moses/FF/MaxSpanFreeNonTermSource.h
@@ -19,14 +19,14 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/Model1Feature.cpp b/moses/FF/Model1Feature.cpp
index d14e2e1bb..23a1fc0a3 100644
--- a/moses/FF/Model1Feature.cpp
+++ b/moses/FF/Model1Feature.cpp
@@ -183,7 +183,7 @@ void Model1Feature::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
const Sentence& sentence = static_cast<const Sentence&>(input);
float score = 0.0;
diff --git a/moses/FF/Model1Feature.h b/moses/FF/Model1Feature.h
index ba192b1e7..703443385 100644
--- a/moses/FF/Model1Feature.h
+++ b/moses/FF/Model1Feature.h
@@ -66,7 +66,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{};
void EvaluateWithSourceContext(const InputType &input
@@ -74,7 +74,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const
diff --git a/moses/FF/NieceTerminal.cpp b/moses/FF/NieceTerminal.cpp
index 50f3b9a5c..edfbc6540 100644
--- a/moses/FF/NieceTerminal.cpp
+++ b/moses/FF/NieceTerminal.cpp
@@ -27,7 +27,7 @@ std::vector<float> NieceTerminal::DefaultWeights() const
void NieceTerminal::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
targetPhrase.SetRuleSource(source);
}
@@ -37,7 +37,7 @@ void NieceTerminal::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
assert(stackVec);
diff --git a/moses/FF/NieceTerminal.h b/moses/FF/NieceTerminal.h
index 71e61fc67..18cdfb2ce 100644
--- a/moses/FF/NieceTerminal.h
+++ b/moses/FF/NieceTerminal.h
@@ -22,13 +22,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/OSM-Feature/OpSequenceModel.cpp b/moses/FF/OSM-Feature/OpSequenceModel.cpp
index 4d9d6b44f..d12ddcd52 100644
--- a/moses/FF/OSM-Feature/OpSequenceModel.cpp
+++ b/moses/FF/OSM-Feature/OpSequenceModel.cpp
@@ -45,7 +45,7 @@ void OpSequenceModel::Load()
void OpSequenceModel:: EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
osmHypothesis obj;
@@ -82,7 +82,7 @@ void OpSequenceModel:: EvaluateInIsolation(const Phrase &source
obj.computeOSMFeature(startIndex,myBitmap);
obj.calculateOSMProb(*OSM);
obj.populateScores(scores,numFeatures);
- estimatedScore.PlusEquals(this, scores);
+ estimatedScores.PlusEquals(this, scores);
}
diff --git a/moses/FF/OSM-Feature/OpSequenceModel.h b/moses/FF/OSM-Feature/OpSequenceModel.h
index 889a3807e..b97450d6b 100644
--- a/moses/FF/OSM-Feature/OpSequenceModel.h
+++ b/moses/FF/OSM-Feature/OpSequenceModel.h
@@ -42,7 +42,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -52,7 +52,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
virtual const FFState* EmptyHypothesisState(const InputType &input) const;
diff --git a/moses/FF/PhraseBoundaryFeature.h b/moses/FF/PhraseBoundaryFeature.h
index e7669ee20..916225b7d 100644
--- a/moses/FF/PhraseBoundaryFeature.h
+++ b/moses/FF/PhraseBoundaryFeature.h
@@ -59,7 +59,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -68,7 +68,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
void SetParameter(const std::string& key, const std::string& value);
diff --git a/moses/FF/PhraseLengthFeature.cpp b/moses/FF/PhraseLengthFeature.cpp
index 91d5b0c5a..c5598e2ec 100644
--- a/moses/FF/PhraseLengthFeature.cpp
+++ b/moses/FF/PhraseLengthFeature.cpp
@@ -19,7 +19,7 @@ PhraseLengthFeature::PhraseLengthFeature(const std::string &line)
void PhraseLengthFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
// get length of source and target phrase
size_t targetLength = targetPhrase.GetSize();
diff --git a/moses/FF/PhraseLengthFeature.h b/moses/FF/PhraseLengthFeature.h
index 9f05e25a1..3faecbcfe 100644
--- a/moses/FF/PhraseLengthFeature.h
+++ b/moses/FF/PhraseLengthFeature.h
@@ -36,7 +36,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -45,7 +45,7 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
};
diff --git a/moses/FF/PhraseOrientationFeature.cpp b/moses/FF/PhraseOrientationFeature.cpp
index ab6f52976..d51a8c290 100644
--- a/moses/FF/PhraseOrientationFeature.cpp
+++ b/moses/FF/PhraseOrientationFeature.cpp
@@ -109,7 +109,7 @@ void PhraseOrientationFeature::LoadWordList(const std::string& filename,
void PhraseOrientationFeature::EvaluateInIsolation(const Phrase &source,
const TargetPhrase &targetPhrase,
ScoreComponentCollection &scoreBreakdown,
- ScoreComponentCollection &estimatedScore) const
+ ScoreComponentCollection &estimatedScores) const
{
targetPhrase.SetRuleSource(source);
diff --git a/moses/FF/PhraseOrientationFeature.h b/moses/FF/PhraseOrientationFeature.h
index 25977468c..82d3928d9 100644
--- a/moses/FF/PhraseOrientationFeature.h
+++ b/moses/FF/PhraseOrientationFeature.h
@@ -294,14 +294,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const
+ , ScoreComponentCollection *estimatedScores = NULL) const
{};
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/PhrasePairFeature.cpp b/moses/FF/PhrasePairFeature.cpp
index 99d141c30..5cee6d437 100644
--- a/moses/FF/PhrasePairFeature.cpp
+++ b/moses/FF/PhrasePairFeature.cpp
@@ -118,7 +118,7 @@ void PhrasePairFeature::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
const Phrase& source = inputPath.GetPhrase();
if (m_domainTrigger) {
@@ -237,7 +237,7 @@ void PhrasePairFeature::EvaluateWithSourceContext(const InputType &input
void PhrasePairFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
if (m_simple) {
util::StringStream namestr;
diff --git a/moses/FF/PhrasePairFeature.h b/moses/FF/PhrasePairFeature.h
index d2a427b47..a817c2d6c 100644
--- a/moses/FF/PhrasePairFeature.h
+++ b/moses/FF/PhrasePairFeature.h
@@ -52,7 +52,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
@@ -62,7 +62,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateWhenApplied(const Hypothesis& hypo,
ScoreComponentCollection* accumulator) const {
diff --git a/moses/FF/PhrasePenalty.cpp b/moses/FF/PhrasePenalty.cpp
index 5e0d932ba..1f709787f 100644
--- a/moses/FF/PhrasePenalty.cpp
+++ b/moses/FF/PhrasePenalty.cpp
@@ -18,7 +18,7 @@ PhrasePenalty::PhrasePenalty(const std::string &line)
void PhrasePenalty::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
if (m_perPhraseTable) {
const PhraseDictionary *pt = targetPhrase.GetContainer();
diff --git a/moses/FF/PhrasePenalty.h b/moses/FF/PhrasePenalty.h
index 020161956..e6bda3435 100644
--- a/moses/FF/PhrasePenalty.h
+++ b/moses/FF/PhrasePenalty.h
@@ -17,7 +17,7 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWhenApplied(const Hypothesis& hypo,
ScoreComponentCollection* accumulator) const {
@@ -34,7 +34,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/ReferenceComparison.h b/moses/FF/ReferenceComparison.h
index 917b6964d..383ba1ae0 100644
--- a/moses/FF/ReferenceComparison.h
+++ b/moses/FF/ReferenceComparison.h
@@ -19,7 +19,7 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
virtual void EvaluateWithSourceContext(const InputType &input
@@ -27,7 +27,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/RulePairUnlexicalizedSource.cpp b/moses/FF/RulePairUnlexicalizedSource.cpp
index 102ab0733..236bf76af 100644
--- a/moses/FF/RulePairUnlexicalizedSource.cpp
+++ b/moses/FF/RulePairUnlexicalizedSource.cpp
@@ -41,7 +41,7 @@ void RulePairUnlexicalizedSource::SetParameter(const std::string& key, const std
void RulePairUnlexicalizedSource::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
const Factor* targetPhraseLHS = targetPhrase.GetTargetLHS()[0];
if ( !m_glueRules && (targetPhraseLHS == m_glueTargetLHS) ) {
diff --git a/moses/FF/RulePairUnlexicalizedSource.h b/moses/FF/RulePairUnlexicalizedSource.h
index e6a3c62fa..a5d2739e0 100644
--- a/moses/FF/RulePairUnlexicalizedSource.h
+++ b/moses/FF/RulePairUnlexicalizedSource.h
@@ -24,14 +24,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const
+ , ScoreComponentCollection *estimatedScores = NULL) const
{}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/RuleScope.cpp b/moses/FF/RuleScope.cpp
index 3f040c2ee..8a18e0a28 100644
--- a/moses/FF/RuleScope.cpp
+++ b/moses/FF/RuleScope.cpp
@@ -23,7 +23,7 @@ bool IsAmbiguous(const Word &word, bool sourceSyntax)
void RuleScope::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
if (IsGlueRule(source)) {
return;
@@ -67,12 +67,12 @@ void RuleScope::EvaluateInIsolation(const Phrase &source
scores[score] = 1;
if (m_futureCostOnly) {
- estimatedScore.PlusEquals(this, scores);
+ estimatedScores.PlusEquals(this, scores);
} else {
scoreBreakdown.PlusEquals(this, scores);
}
} else if (m_futureCostOnly) {
- estimatedScore.PlusEquals(this, score);
+ estimatedScores.PlusEquals(this, score);
} else {
scoreBreakdown.PlusEquals(this, score);
}
diff --git a/moses/FF/RuleScope.h b/moses/FF/RuleScope.h
index 87099dac3..473cf22f5 100644
--- a/moses/FF/RuleScope.h
+++ b/moses/FF/RuleScope.h
@@ -18,14 +18,14 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/SetSourcePhrase.cpp b/moses/FF/SetSourcePhrase.cpp
index 9c5f3b07a..24671aac6 100644
--- a/moses/FF/SetSourcePhrase.cpp
+++ b/moses/FF/SetSourcePhrase.cpp
@@ -13,7 +13,7 @@ SetSourcePhrase::SetSourcePhrase(const std::string &line)
void SetSourcePhrase::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
targetPhrase.SetRuleSource(source);
}
diff --git a/moses/FF/SetSourcePhrase.h b/moses/FF/SetSourcePhrase.h
index fc965685f..80e771ff9 100644
--- a/moses/FF/SetSourcePhrase.h
+++ b/moses/FF/SetSourcePhrase.h
@@ -18,14 +18,14 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/SkeletonStatefulFF.cpp b/moses/FF/SkeletonStatefulFF.cpp
index e44823bbd..4b077335e 100644
--- a/moses/FF/SkeletonStatefulFF.cpp
+++ b/moses/FF/SkeletonStatefulFF.cpp
@@ -18,7 +18,7 @@ SkeletonStatefulFF::SkeletonStatefulFF(const std::string &line)
void SkeletonStatefulFF::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{}
void SkeletonStatefulFF::EvaluateWithSourceContext(const InputType &input
@@ -26,7 +26,7 @@ void SkeletonStatefulFF::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{}
void SkeletonStatefulFF::EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/SkeletonStatefulFF.h b/moses/FF/SkeletonStatefulFF.h
index c861abbdf..bed54753c 100644
--- a/moses/FF/SkeletonStatefulFF.h
+++ b/moses/FF/SkeletonStatefulFF.h
@@ -40,13 +40,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const;
diff --git a/moses/FF/SkeletonStatelessFF.cpp b/moses/FF/SkeletonStatelessFF.cpp
index d75ae8047..8474efe76 100644
--- a/moses/FF/SkeletonStatelessFF.cpp
+++ b/moses/FF/SkeletonStatelessFF.cpp
@@ -16,7 +16,7 @@ SkeletonStatelessFF::SkeletonStatelessFF(const std::string &line)
void SkeletonStatelessFF::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
// dense scores
vector<float> newScores(m_numScoreComponents);
@@ -34,7 +34,7 @@ void SkeletonStatelessFF::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
if (targetPhrase.GetNumNonTerminals()) {
vector<float> newScores(m_numScoreComponents);
diff --git a/moses/FF/SkeletonStatelessFF.h b/moses/FF/SkeletonStatelessFF.h
index b5ef03df8..0dc46e214 100644
--- a/moses/FF/SkeletonStatelessFF.h
+++ b/moses/FF/SkeletonStatelessFF.h
@@ -18,13 +18,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const;
diff --git a/moses/FF/SoftMatchingFeature.h b/moses/FF/SoftMatchingFeature.h
index 4b270008b..ae2380dcb 100644
--- a/moses/FF/SoftMatchingFeature.h
+++ b/moses/FF/SoftMatchingFeature.h
@@ -25,13 +25,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {};
+ , ScoreComponentCollection &estimatedScores) const {};
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {};
+ , ScoreComponentCollection *estimatedScores = NULL) const {};
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/SoftSourceSyntacticConstraintsFeature.cpp b/moses/FF/SoftSourceSyntacticConstraintsFeature.cpp
index 9a0a1dddf..3802162bc 100644
--- a/moses/FF/SoftSourceSyntacticConstraintsFeature.cpp
+++ b/moses/FF/SoftSourceSyntacticConstraintsFeature.cpp
@@ -288,7 +288,7 @@ void SoftSourceSyntacticConstraintsFeature::EvaluateWithSourceContext(const Inpu
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
assert(stackVec);
diff --git a/moses/FF/SoftSourceSyntacticConstraintsFeature.h b/moses/FF/SoftSourceSyntacticConstraintsFeature.h
index 2ed059764..d2ee393f1 100644
--- a/moses/FF/SoftSourceSyntacticConstraintsFeature.h
+++ b/moses/FF/SoftSourceSyntacticConstraintsFeature.h
@@ -35,7 +35,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
targetPhrase.SetRuleSource(source);
};
@@ -44,7 +44,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const
diff --git a/moses/FF/SourceGHKMTreeInputMatchFeature.cpp b/moses/FF/SourceGHKMTreeInputMatchFeature.cpp
index 8f87321a6..148eb3013 100644
--- a/moses/FF/SourceGHKMTreeInputMatchFeature.cpp
+++ b/moses/FF/SourceGHKMTreeInputMatchFeature.cpp
@@ -37,7 +37,7 @@ void SourceGHKMTreeInputMatchFeature::EvaluateWithSourceContext(const InputType
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
const Range& range = inputPath.GetWordsRange();
size_t startPos = range.GetStartPos();
diff --git a/moses/FF/SourceGHKMTreeInputMatchFeature.h b/moses/FF/SourceGHKMTreeInputMatchFeature.h
index 102fd059f..b67649b26 100644
--- a/moses/FF/SourceGHKMTreeInputMatchFeature.h
+++ b/moses/FF/SourceGHKMTreeInputMatchFeature.h
@@ -20,14 +20,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {};
+ , ScoreComponentCollection &estimatedScores) const {};
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/SourceWordDeletionFeature.cpp b/moses/FF/SourceWordDeletionFeature.cpp
index 7e46ddabc..f8103e1ee 100644
--- a/moses/FF/SourceWordDeletionFeature.cpp
+++ b/moses/FF/SourceWordDeletionFeature.cpp
@@ -64,7 +64,7 @@ bool SourceWordDeletionFeature::IsUseable(const FactorMask &mask) const
void SourceWordDeletionFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
const AlignmentInfo &alignmentInfo = targetPhrase.GetAlignTerm();
ComputeFeatures(source, targetPhrase, &scoreBreakdown, alignmentInfo);
diff --git a/moses/FF/SourceWordDeletionFeature.h b/moses/FF/SourceWordDeletionFeature.h
index 029520229..a290b83de 100644
--- a/moses/FF/SourceWordDeletionFeature.h
+++ b/moses/FF/SourceWordDeletionFeature.h
@@ -30,13 +30,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/SpanLength.cpp b/moses/FF/SpanLength.cpp
index aee9ffe63..1a413013c 100644
--- a/moses/FF/SpanLength.cpp
+++ b/moses/FF/SpanLength.cpp
@@ -24,7 +24,7 @@ SpanLength::SpanLength(const std::string &line)
void SpanLength::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
targetPhrase.SetRuleSource(source);
}
@@ -34,7 +34,7 @@ void SpanLength::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
assert(stackVec);
diff --git a/moses/FF/SpanLength.h b/moses/FF/SpanLength.h
index 8fb749207..3a13d3a3d 100644
--- a/moses/FF/SpanLength.h
+++ b/moses/FF/SpanLength.h
@@ -18,14 +18,14 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/SparseHieroReorderingFeature.h b/moses/FF/SparseHieroReorderingFeature.h
index c6bf3d986..79fb0f19b 100644
--- a/moses/FF/SparseHieroReorderingFeature.h
+++ b/moses/FF/SparseHieroReorderingFeature.h
@@ -34,14 +34,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/SyntaxRHS.cpp b/moses/FF/SyntaxRHS.cpp
index ce4ec4f42..2aaf1d5f9 100644
--- a/moses/FF/SyntaxRHS.cpp
+++ b/moses/FF/SyntaxRHS.cpp
@@ -17,7 +17,7 @@ SyntaxRHS::SyntaxRHS(const std::string &line)
void SyntaxRHS::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
}
@@ -26,7 +26,7 @@ void SyntaxRHS::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
assert(stackVec);
diff --git a/moses/FF/SyntaxRHS.h b/moses/FF/SyntaxRHS.h
index e864f4585..0096e286a 100644
--- a/moses/FF/SyntaxRHS.h
+++ b/moses/FF/SyntaxRHS.h
@@ -18,13 +18,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/TargetBigramFeature.h b/moses/FF/TargetBigramFeature.h
index 738793a57..200eca060 100644
--- a/moses/FF/TargetBigramFeature.h
+++ b/moses/FF/TargetBigramFeature.h
@@ -53,12 +53,12 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/TargetNgramFeature.h b/moses/FF/TargetNgramFeature.h
index 8039971b4..5bc2fc953 100644
--- a/moses/FF/TargetNgramFeature.h
+++ b/moses/FF/TargetNgramFeature.h
@@ -220,7 +220,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -230,7 +230,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
void SetParameter(const std::string& key, const std::string& value);
diff --git a/moses/FF/TargetWordInsertionFeature.cpp b/moses/FF/TargetWordInsertionFeature.cpp
index 0bde0b92a..73dbcd539 100644
--- a/moses/FF/TargetWordInsertionFeature.cpp
+++ b/moses/FF/TargetWordInsertionFeature.cpp
@@ -56,7 +56,7 @@ void TargetWordInsertionFeature::Load()
void TargetWordInsertionFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
const AlignmentInfo &alignmentInfo = targetPhrase.GetAlignTerm();
ComputeFeatures(source, targetPhrase, &scoreBreakdown, alignmentInfo);
diff --git a/moses/FF/TargetWordInsertionFeature.h b/moses/FF/TargetWordInsertionFeature.h
index 28943a023..b30e4302c 100644
--- a/moses/FF/TargetWordInsertionFeature.h
+++ b/moses/FF/TargetWordInsertionFeature.h
@@ -30,13 +30,13 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateWhenApplied(const Hypothesis& hypo,
ScoreComponentCollection* accumulator) const {
diff --git a/moses/FF/TreeStructureFeature.h b/moses/FF/TreeStructureFeature.h
index fec3a1446..361e8cc6a 100644
--- a/moses/FF/TreeStructureFeature.h
+++ b/moses/FF/TreeStructureFeature.h
@@ -66,13 +66,13 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {};
+ , ScoreComponentCollection &estimatedScores) const {};
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {};
+ , ScoreComponentCollection *estimatedScores = NULL) const {};
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const {
diff --git a/moses/FF/UnalignedWordCountFeature.cpp b/moses/FF/UnalignedWordCountFeature.cpp
index 720d9483f..f1e2a8d9b 100644
--- a/moses/FF/UnalignedWordCountFeature.cpp
+++ b/moses/FF/UnalignedWordCountFeature.cpp
@@ -21,7 +21,7 @@ UnalignedWordCountFeature::UnalignedWordCountFeature(const std::string &line)
void UnalignedWordCountFeature::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
const AlignmentInfo &alignmentInfo = targetPhrase.GetAlignTerm();
const size_t sourceLength = source.GetSize();
diff --git a/moses/FF/UnalignedWordCountFeature.h b/moses/FF/UnalignedWordCountFeature.h
index a229b3364..807b2683d 100644
--- a/moses/FF/UnalignedWordCountFeature.h
+++ b/moses/FF/UnalignedWordCountFeature.h
@@ -19,14 +19,14 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/UnknownWordPenaltyProducer.h b/moses/FF/UnknownWordPenaltyProducer.h
index 50b33177c..023d02016 100644
--- a/moses/FF/UnknownWordPenaltyProducer.h
+++ b/moses/FF/UnknownWordPenaltyProducer.h
@@ -45,7 +45,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
@@ -55,7 +55,7 @@ public:
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
};
diff --git a/moses/FF/WordPenaltyProducer.cpp b/moses/FF/WordPenaltyProducer.cpp
index 063a1c5f5..72959984a 100644
--- a/moses/FF/WordPenaltyProducer.cpp
+++ b/moses/FF/WordPenaltyProducer.cpp
@@ -20,7 +20,7 @@ WordPenaltyProducer::WordPenaltyProducer(const std::string &line)
void WordPenaltyProducer::EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const
+ , ScoreComponentCollection &estimatedScores) const
{
float score = - (float) targetPhrase.GetNumTerminals();
scoreBreakdown.Assign(this, score);
diff --git a/moses/FF/WordPenaltyProducer.h b/moses/FF/WordPenaltyProducer.h
index fca021966..34159eb9c 100644
--- a/moses/FF/WordPenaltyProducer.h
+++ b/moses/FF/WordPenaltyProducer.h
@@ -30,7 +30,7 @@ public:
virtual void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const;
+ , ScoreComponentCollection &estimatedScores) const;
void EvaluateWhenApplied(const Hypothesis& hypo,
ScoreComponentCollection* accumulator) const {
}
@@ -45,7 +45,7 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const {
+ , ScoreComponentCollection *estimatedScores = NULL) const {
}
void EvaluateTranslationOptionListWithSourceContext(const InputType &input
diff --git a/moses/FF/WordTranslationFeature.cpp b/moses/FF/WordTranslationFeature.cpp
index 088b55e55..2231a2941 100644
--- a/moses/FF/WordTranslationFeature.cpp
+++ b/moses/FF/WordTranslationFeature.cpp
@@ -142,7 +142,7 @@ void WordTranslationFeature::EvaluateWithSourceContext(const InputType &input
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore) const
+ , ScoreComponentCollection *estimatedScores) const
{
const Sentence& sentence = static_cast<const Sentence&>(input);
const AlignmentInfo &alignment = targetPhrase.GetAlignTerm();
diff --git a/moses/FF/WordTranslationFeature.h b/moses/FF/WordTranslationFeature.h
index accd5d594..85d1710ce 100644
--- a/moses/FF/WordTranslationFeature.h
+++ b/moses/FF/WordTranslationFeature.h
@@ -47,12 +47,12 @@ public:
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const;
+ , ScoreComponentCollection *estimatedScores = NULL) const;
void EvaluateInIsolation(const Phrase &source
, const TargetPhrase &targetPhrase
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection &estimatedScore) const {
+ , ScoreComponentCollection &estimatedScores) const {
}
void EvaluateWhenApplied(const Hypothesis& hypo,
diff --git a/moses/FF/FeatureFunction.h b/moses/FF/FeatureFunction.h
index 5e01e7df6..40307b871 100644
--- a/moses/FF/FeatureFunction.h
+++ b/moses/FF/FeatureFunction.h
@@ -151,7 +151,7 @@ public:
virtual void
EvaluateInIsolation(const Phrase &source, const TargetPhrase &targetPhrase,
ScoreComponentCollection& scoreBreakdown,
- ScoreComponentCollection& estimatedScore) const = 0;
+ ScoreComponentCollection& estimatedScores) const = 0;
// for context-dependent processing
static void SetupAll(TranslationTask const& task);
@@ -163,13 +163,13 @@ public:
// 'stackVec' is a vector of chart cells that the RHS non-terms cover.
// It is guaranteed to be in the same order as the non-terms in the source phrase.
// For pb models, stackvec is NULL.
// No FF should set estimatedScore in both overloads!
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
, const TargetPhrase &targetPhrase
, const StackVec *stackVec
, ScoreComponentCollection &scoreBreakdown
- , ScoreComponentCollection *estimatedScore = NULL) const = 0;
+ , ScoreComponentCollection *estimatedScores = NULL) const = 0;
// This method is called once all the translation options are retrieved from the phrase table, and
// just before search.
@@ -177,7 +177,7 @@ public:
// 'stackVec' is a vector of chart cells that the RHS non-terms cover.
// It is guaranteed to be in the same order as the non-terms in the source phrase.
// For pb models, stackvec is NULL.
// No FF should set estimatedScore in both overloads!
virtual void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const = 0;
@@ -163,13 +163,13 @@ public:
// It is guaranteed to be in the same order as the non-terms in the source phrase.
// For pb models, stackvec is NULL.
- // No FF should set estimatedScore in both overloads!
+ // No FF should set estimatedScores in both overloads!
virtual void EvaluateWithSourceContext(const InputType &input
, const InputPath &inputPath
@@ -177,7 +177,7 @@ public:
// It is guaranteed to be in the same order as the non-terms in the source phrase.
// For pb models, stackvec is NULL.
- // No FF should set estimatedScore in both overloads!
+ // No FF should set estimatedScores in both overloads!
virtual void EvaluateTranslationOptionListWithSourceContext(const InputType &input
, const TranslationOptionList &translationOptionList) const = 0;